Update the copyright year.
[rsync/rsync.git] / cleanup.c
index 2ded302..19ef072 100644 (file)
--- a/cleanup.c
+++ b/cleanup.c
@@ -4,7 +4,7 @@
  * Copyright (C) 1996-2000 Andrew Tridgell
  * Copyright (C) 1996 Paul Mackerras
  * Copyright (C) 2002 Martin Pool
- * Copyright (C) 2003-2007 Wayne Davison
+ * Copyright (C) 2003-2009 Wayne Davison
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,8 @@ extern int am_server;
 extern int am_daemon;
 extern int io_error;
 extern int keep_partial;
-extern int log_got_error;
+extern int got_xfer_error;
+extern int output_needs_newline;
 extern char *partial_dir;
 extern char *logfile_name;
 
@@ -104,7 +105,7 @@ NORETURN void _exit_cleanup(int code, const char *file, int line)
                code = exit_code;
 
        /* If this is the exit at the end of the run, the server side
* should not attempt to output a message (see log.c). */
        if (am_server && code == 0)
                am_server = 2;
 
@@ -115,7 +116,12 @@ NORETURN void _exit_cleanup(int code, const char *file, int line)
 
                exit_code = unmodified_code = code;
 
-               if (verbose > 3) {
+               if (output_needs_newline) {
+                       fputc('\n', stdout);
+                       output_needs_newline = 0;
+               }
+
+               if (DEBUG_GTE(EXIT, 2)) {
                        rprintf(FINFO,
                                "_exit_cleanup(code=%d, file=%s, line=%d): entered\n",
                                code, file, line);
@@ -174,17 +180,17 @@ NORETURN void _exit_cleanup(int code, const char *file, int line)
                                code = exit_code = RERR_DEL_LIMIT;
                        if (io_error & IOERR_VANISHED)
                                code = exit_code = RERR_VANISHED;
-                       if (io_error & IOERR_GENERAL || log_got_error)
+                       if (io_error & IOERR_GENERAL || got_xfer_error)
                                code = exit_code = RERR_PARTIAL;
                }
 
-               if (code || am_daemon || (logfile_name && (am_server || !verbose)))
+               if (code || am_daemon || (logfile_name && (am_server || !INFO_GTE(STATS, 1))))
                        log_exit(code, file, line);
 
                /* FALLTHROUGH */
 #include "case_N.h"
 
-               if (verbose > 2) {
+               if (DEBUG_GTE(EXIT, 1)) {
                        rprintf(FINFO,
                                "_exit_cleanup(code=%d, file=%s, line=%d): "
                                "about to call exit(%d)\n",
@@ -104,7 +105,7 @@ NORETURN void _exit_cleanup(int code, const char *file, int line)
 
        /* If this is the exit at the end of the run, the server side
-        * should not attempt to output a message (see log.c). */
+        * should not attempt to output a message (see log_exit()). */
        if (am_server && code == 0)
                am_server = 2;